@@ -19,20 +19,14 @@
 """Console script for ecs_composex."""
 
 import argparse
-import os
 import sys
 import warnings
 
-from boto3 import session
-
+from ecs_composex.common import LOG
 from ecs_composex.common import keyisset
-from ecs_composex.common import LOG, load_composex_file
-from ecs_composex.common.aws import get_curated_azs, get_account_id
-from ecs_composex.common.cfn_params import USE_FLEET_T
-from ecs_composex.common.cfn_tools import build_config_template_file
-from ecs_composex.common.ecs_composex import XFILE_DEST, DIR_DEST
-from ecs_composex.common.files import FileArtifact
-from ecs_composex.common.stacks import render_final_template
+from ecs_composex.common.aws import deploy
+from ecs_composex.common.settings import ComposeXSettings
+from ecs_composex.common.stacks import process_stacks
 from ecs_composex.compute.compute_params import CLUSTER_NAME_T
 from ecs_composex.ecs_composex import generate_full_template
 from ecs_composex.vpc.vpc_params import (
@@ -40,45 +34,9 @@ from ecs_composex.vpc.vpc_params import (
     PUBLIC_SUBNETS_T,
     STORAGE_SUBNETS_T,
     VPC_ID_T,
-    VPC_MAP_ID_T,
 )
 
-CURATED_AZS = get_curated_azs()
-ACCOUNT_ID = get_account_id()
-BUCKET_NAME = f"cfn-templates-{ACCOUNT_ID[:6]}"
-
-
-def validate_vpc_input(args):
-    """
-    Function to validate the VPC arguments are all present
-
-    :param args: Parser arguments
-    :type args: dict
-
-    :raise: KeyError if missing argument when not creating VPC
-
-    """
-    nocreate_requirements = [
-        PUBLIC_SUBNETS_T,
-        APP_SUBNETS_T,
-        STORAGE_SUBNETS_T,
-        VPC_ID_T,
-        VPC_MAP_ID_T,
-    ]
-    if not keyisset("CreateVpc", args):
-        for key in nocreate_requirements:
-            if not keyisset(key, args):
-                warnings.warn(
-                    f"{key} was not provided. Not adding to the parameters file",
-                    UserWarning,
-                )
-    else:
-        for key in nocreate_requirements:
-            if keyisset(key, args):
-                LOG.info(args[key])
-                warnings.warn(
-                    f"Creating VPC is set. Ignoring value for {key}", UserWarning
-                )
+from ecs_composex.dns.dns_params import PRIVATE_DNS_ZONE_ID_T
 
 
 def validate_cluster_input(args):
@@ -95,22 +53,26 @@ def validate_cluster_input(args):
 
 
 def main_parser():
-    """Console script for ecs_composex."""
+    """
+    Console script for ecs_composex.
+    """
+    SUBNETS_DESC = "List of Subnet IDs to use for the cluster when not creating VPC"
     parser = argparse.ArgumentParser()
     #  Generic settings
     parser.add_argument(
-        "-f",
-        "--docker-compose-file",
-        dest=XFILE_DEST,
+        "-n",
+        "--name",
+        help="Name of your stack",
         required=True,
-        help="Path to the Docker compose file",
+        type=str,
+        dest=ComposeXSettings.name_arg,
     )
     parser.add_argument(
-        "-o",
-        "--output-file",
-        required=False,
-        default=f"{os.path.basename(os.path.dirname(__file__))}.yml",
-        help="Output file. Extension determines the file format",
+        "-f",
+        "--docker-compose-file",
+        dest=ComposeXSettings.input_file_arg,
+        required=True,
+        help="Path to the Docker compose file",
     )
     parser.add_argument(
         "-d",
@@ -118,7 +80,16 @@ def main_parser():
         required=False,
         help="Output directory to write all the templates to.",
         type=str,
-        dest=DIR_DEST,
+        dest=ComposeXSettings.output_dir_arg,
+        default=ComposeXSettings.default_output_dir,
+    )
+    parser.add_argument(
+        "--format",
+        help="Defines the format you want to use.",
+        type=str,
+        dest=ComposeXSettings.format_arg,
+        choices=ComposeXSettings.allowed_formats,
+        default=ComposeXSettings.default_format,
     )
     parser.add_argument(
         "--cfn-config-file",
@@ -137,17 +108,16 @@ def main_parser():
     parser.add_argument(
         "--region",
         required=False,
-        default=session.Session().region_name,
-        dest="AwsRegion",
+        dest=ComposeXSettings.region_arg,
         help="Specify the region you want to build for"
         "default use default region from config or environment vars",
     )
     parser.add_argument(
         "--az",
-        dest="AwsAzs",
+        dest=ComposeXSettings.zones_arg,
+        default=ComposeXSettings.default_azs,
         action="append",
         required=False,
-        default=CURATED_AZS,
         help="List AZs you want to deploy to specifically within the region",
     )
     parser.add_argument(
@@ -155,7 +125,6 @@ def main_parser():
         "--bucket-name",
         type=str,
         required=False,
-        default=BUCKET_NAME,
         help="Bucket name to upload the templates to",
         dest="BucketName",
     )
@@ -164,7 +133,15 @@ def main_parser():
         action="store_true",
         default=False,
         help="Whether the templates should be uploaded or not.",
-        dest="NoUpload",
+        dest=ComposeXSettings.no_upload_arg,
+    )
+    parser.add_argument(
+        "--deploy",
+        action="store_true",
+        default=False,
+        required=False,
+        help="Whether or not you would like to deploy the stack to CFN.",
+        dest=ComposeXSettings.deploy_arg,
     )
     # VPC SETTINGS
     parser.add_argument(
@@ -173,13 +150,13 @@ def main_parser():
         default=False,
         action="store_true",
         help="Create a VPC for this deployment",
-        dest="CreateVpc",
+        dest=ComposeXSettings.create_vpc_arg,
     )
     parser.add_argument(
         "--vpc-cidr",
         required=False,
-        default="192.168.36.0/22",
-        dest="VpcCidr",
+        default=ComposeXSettings.default_vpc_cidr,
+        dest=ComposeXSettings.vpc_cidr_arg,
         help="Specify the VPC CIDR if you use --create-vpc",
     )
     parser.add_argument(
@@ -194,26 +171,26 @@ def main_parser():
         required=False,
         dest=PUBLIC_SUBNETS_T,
         action="append",
-        help="List of Subnet IDs to use for the cluster when not creating VPC",
+        help=SUBNETS_DESC,
     )
     parser.add_argument(
         "--app-subnets",
         required=False,
         dest=APP_SUBNETS_T,
         action="append",
-        help="List of Subnet IDs to use for the cluster when not creating VPC",
+        help=SUBNETS_DESC,
     )
     parser.add_argument(
         "--storage-subnets",
         required=False,
         dest=STORAGE_SUBNETS_T,
         action="append",
-        help="List of Subnet IDs to use for the cluster when not creating VPC",
+        help=SUBNETS_DESC,
     )
     parser.add_argument(
         "--discovery-map-id",
-        "--map",
-        dest=VPC_MAP_ID_T,
+        "--cloud-map-id",
+        dest=PRIVATE_DNS_ZONE_ID_T,
         required=False,
         help="Service Discovery ID, ie. ns-xxx",
     )
@@ -245,25 +222,10 @@ def main_parser():
         required=False,
         default=False,
         action="store_true",
-        dest=USE_FLEET_T,
+        dest=ComposeXSettings.create_spotfleet_arg,
         help="Runs spotfleet for EC2. If used in combination "
         "of --use-fargate, it will create an additional SpotFleet",
     )
-    parser.add_argument(
-        "--add-compute-resources",
-        dest="AddComputeResources",
-        action="store_true",
-        help="Whether you want to create a launch template to create EC2 resources for"
-        " to expand the ECS Cluster and run containers on EC2 instances you might have access to.",
-    )
-    #  ECS COMPOSEX SPECIALS
-    parser.add_argument(
-        "--iam-only",
-        default=False,
-        action="store_true",
-        required=False,
-        help="Generates only the IAM roles for the tasks",
-    )
 
     parser.add_argument("_", nargs="*")
     return parser
@@ -272,35 +234,25 @@ def main_parser():
 def main():
     parser = main_parser()
     args = parser.parse_args()
+    settings = ComposeXSettings(**vars(args))
+    settings.set_bucket_name_from_account_id()
+    settings.set_azs_from_api()
+    LOG.debug(settings)
 
-    kwargs = vars(args)
-    content = load_composex_file(kwargs[XFILE_DEST])
-    validate_vpc_input(vars(args))
+    if settings.deploy and not settings.upload:
+        LOG.warning(
+            "You must update the templates in order to deploy. We won't be deploying."
+        )
+        settings.deploy = False
+
+    # validate_vpc_input(settings)
     validate_cluster_input(vars(args))
 
-    print("Arguments: " + str(args._))
-    templates_and_params = generate_full_template(content, **kwargs)
+    root_stack = generate_full_template(settings)
+    process_stacks(root_stack, settings)
 
-    render_final_template(templates_and_params[0])
-    cfn_config = build_config_template_file(
-        config={}, parameters=templates_and_params[1]
-    )
-    if keyisset("CfnConfigFile", vars(args)):
-        config_file_name = args.CfnConfigFile
-    else:
-        config_file_name = f"{args.output_file.split('.')[0]}.config.json"
-    config_file = FileArtifact(config_file_name, content=cfn_config, **vars(args))
-    params_file = FileArtifact(
-        f"{args.output_file.split('.')[0]}.params.json",
-        content=templates_and_params[1],
-        **vars(args),
-    )
-    template_file = FileArtifact(
-        args.output_file, template=templates_and_params[0], **vars(args)
-    )
-    template_file.create()
-    params_file.create()
-    config_file.create()
+    if settings.deploy:
+        deploy(settings, root_stack)
 
 
 if __name__ == "__main__":
