@@ -18,21 +18,16 @@
 
 """Common Conditions across the templates"""
 
-from troposphere import Condition, Not, Ref, Equals, And
+from troposphere import Condition, Not, Ref, Equals, And, If
 
 from ecs_composex.common import cfn_params
+from ecs_composex.vpc import vpc_params
 
 USE_STACK_NAME_CON_T = "UseStackName"
 USE_STACK_NAME_CON = Equals(
     Ref(cfn_params.ROOT_STACK_NAME), cfn_params.ROOT_STACK_NAME.Default
 )
 
-USE_CLOUDMAP_CON_T = "UseCloudMapCondition"
-USE_CLOUDMAP_CON = Equals(Ref(cfn_params.USE_CLOUDMAP), "True")
-
-NOT_USE_CLOUDMAP_CON_T = "NotUseCloudMapCondition"
-NOT_USE_CLOUDMAP_CON = Not(Condition(USE_CLOUDMAP_CON_T))
-
 USE_CFN_PARAMS_CON_T = "UseCfnParametersValueCondition"
 USE_CFN_PARAMS_CON = Equals(
     Ref(cfn_params.USE_CFN_PARAMS), cfn_params.USE_CFN_PARAMS.Default
@@ -63,3 +58,32 @@ USE_SPOT_CON = Equals(Ref(cfn_params.USE_FLEET), "True")
 
 NOT_USE_SPOT_CON_T = "NotUseSpotFleetHostsCondition"
 NOT_USE_SPOT_CON = Not(Condition(USE_SPOT_CON_T))
+
+
+def pass_root_stack_name():
+    """
+    Function to add root_stack to a stack parameters
+
+    :return: rootstack name value based on condition
+    """
+    return {
+        cfn_params.ROOT_STACK_NAME_T: If(
+            USE_STACK_NAME_CON_T, Ref("AWS::StackName"), Ref(cfn_params.ROOT_STACK_NAME)
+        )
+    }
+
+
+def define_stack_name(template=None):
+    """
+    Function to return Stack name contstruct.
+    Adds the conditions and parameters if template is given.
+
+    :param troposphere.Template template: the template to add it to.
+    :return:
+    """
+    if template:
+        if USE_STACK_NAME_CON_T not in template.conditions:
+            template.add_condition(USE_STACK_NAME_CON_T, USE_STACK_NAME_CON)
+    return If(
+        USE_STACK_NAME_CON_T, Ref("AWS::StackName"), Ref(cfn_params.ROOT_STACK_NAME)
+    )
