@@ -35,6 +35,14 @@ GENERATED_CLUSTER_NAME_CON = Equals(
     Ref(ecs_params.CLUSTER_NAME), ecs_params.CLUSTER_NAME.Default
 )
 
+NOT_USE_CLUSTER_SG_CON_T = "NotUseClusterSecurityGroupCondition"
+NOT_USE_CLUSTER_SG_CON = Equals(
+    Ref(ecs_params.CLUSTER_SG_ID), ecs_params.CLUSTER_SG_ID.Default
+)
+
+USE_CLUSTER_SG_CON_T = "UseClusterSecurityGroupCondition"
+USE_CLUSTER_SG_CON = Not(Condition(NOT_USE_CLUSTER_SG_CON_T))
+
 CLUSTER_NAME_CON_T = "SetClusterNameFromRootStack"
 CLUSTER_NAME_CON = And(
     Condition(USE_STACK_NAME_CON_T), Condition(GENERATED_CLUSTER_NAME_CON_T)
@@ -42,11 +50,6 @@ CLUSTER_NAME_CON = And(
 SERVICE_COUNT_ZERO_CON_T = "ServiceCountIsZeroCondition"
 SERVICE_COUNT_ZERO_CON = Equals(Ref(ecs_params.SERVICE_COUNT), "0")
 
-MEM_RES_IS_MEM_ALLOC_CON_T = "MemoryReservedIsMemoryAllocatedCondition"
-MEM_RES_IS_MEM_ALLOC_CON = Equals(
-    Ref(ecs_params.MEMORY_RES), ecs_params.MEMORY_RES.Default
-)
-
 USE_FARGATE_CON_T = "UseFargateCondition"
 USE_FARGATE_CON = Equals(Ref(ecs_params.LAUNCH_TYPE), "FARGATE")
 
@@ -62,3 +65,8 @@ NOT_USE_HOSTNAME_CON = Equals(
 
 USE_HOSTNAME_CON_T = "UseMicroserviceHostnameCondition"
 USE_HOSTNAME_CON = Not(Condition(NOT_USE_HOSTNAME_CON_T))
+
+USE_CLUSTER_CAPACITY_PROVIDERS_CON_T = "UseClusterDefaultCapacityProviders"
+USE_CLUSTER_CAPACITY_PROVIDERS_CON = Equals(
+    Ref(ecs_params.LAUNCH_TYPE), ecs_params.LAUNCH_TYPE.Default
+)
