@@ -17,8 +17,8 @@
 
 """ IAM Building block for ECS """
 
-from troposphere import Sub, Ref, AWS_ACCOUNT_ID, AWS_PARTITION, AWS_REGION
-from troposphere.iam import Role, PolicyType, Policy
+from troposphere import Sub, Ref
+from troposphere.iam import Role, PolicyType
 
 from ecs_composex.ecs.ecs_params import (
     SERVICE_NAME_T,
@@ -30,41 +30,6 @@ from ecs_composex.ecs.ecs_params import (
 from ecs_composex.iam import service_role_trust_policy, add_role_boundaries
 
 
-def define_xray_policy():
-    """
-    Function to define the XRAY Policy
-
-    :return: policy
-    :rtype: troposphere.iam.Policy
-    """
-    return Policy(
-        PolicyName="EnableXRay",
-        PolicyDocument={
-            "Version": "2012-10-17",
-            "Statement": [
-                {
-                    "Action": [
-                        "xray:PutTraceSegments",
-                        "xray:PutTelemetryRecords",
-                        "xray:GetSamplingRules",
-                        "xray:GetSamplingTargets",
-                        "xray:GetSamplingStatisticSummaries",
-                    ],
-                    "Effect": "Allow",
-                    "Resource": [
-                        Sub(
-                            f"arn:${{{AWS_PARTITION}}}:xray:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:group/*"
-                        ),
-                        Sub(
-                            f"arn:${{{AWS_PARTITION}}}:xray:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:sampling-rule/*"
-                        ),
-                    ],
-                }
-            ],
-        },
-    )
-
-
 def add_service_roles(template, config):
     """
     Function to create the IAM roles for the ECS task
@@ -110,17 +75,6 @@ def add_service_roles(template, config):
                     "Action": ["ecs:DiscoverPollEndpoint", "ecs:Poll", "ecs:Submit*"],
                     "Resource": ["*"],
                 },
-                {
-                    "Sid": "AllowCloudWatchLoggingToSpecificLogGroup",
-                    "Effect": "Allow",
-                    "Action": ["logs:CreateLogStream", "logs:PutLogEvents"],
-                    "Resource": [
-                        Sub(
-                            f"arn:${{{AWS_PARTITION}}}:logs:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:log-group:"
-                            f"${{{CLUSTER_NAME_T}}}:*"
-                        )
-                    ],
-                },
                 {
                     "Sid": "AllowsEcsAgentToPerformActionsForMicroservice",
                     "Effect": "Allow",
@@ -145,14 +99,15 @@ def add_service_roles(template, config):
         Roles=[Ref(execution_role)],
     )
     policies = []
+    managed_policies = []
     if config and config.use_xray:
-        policies.append(define_xray_policy())
+        managed_policies.append("arn:aws:iam::aws:policy/AWSXRayDaemonWriteAccess")
     role = Role(
         TASK_ROLE_T,
         template=template,
         AssumeRolePolicyDocument=service_role_trust_policy("ecs-tasks"),
         Description=Sub(f"TaskRole - ${{{SERVICE_NAME_T}}} in ${{{CLUSTER_NAME_T}}}"),
-        ManagedPolicyArns=[],
+        ManagedPolicyArns=managed_policies,
         Policies=policies,
     )
     if config and config.boundary:
