@@ -26,9 +26,10 @@ from troposphere.iam import PolicyType
 from troposphere.ecs import ContainerDefinition
 
 from ecs_composex.common import keyisset, LOG
-from ecs_composex.common.outputs import define_import
+from ecs_composex.common.outputs import get_import_value
 from ecs_composex.ecs.ecs_iam import define_service_containers
 from ecs_composex.ecs.ecs_params import TASK_ROLE_T, EXEC_ROLE_T, SG_T
+from ecs_composex.ecs.ecs_container_config import extend_container_secrets
 from ecs_composex.rds.rds_params import (
     DB_EXPORT_SECRET_ARN_T,
     DB_SECRET_POLICY_NAME,
@@ -87,7 +88,7 @@ def define_db_secret_import(db_name):
     :param str db_name: Name of the DB as defined in the compose file.
     :return: the import function to the DB.
     """
-    return define_import(db_name, DB_EXPORT_SECRET_ARN_T)
+    return get_import_value(db_name, DB_EXPORT_SECRET_ARN_T)
 
 
 def add_security_group_ingress(service_stack, db_name):
@@ -98,47 +99,69 @@ def add_security_group_ingress(service_stack, db_name):
     :param str db_name: the name of the database to use for imports
     """
     service_template = service_stack.stack_template
-    sg_id = define_import(db_name, DB_EXPORT_SG_ID_T)
-    port = define_import(db_name, DB_EXPORT_PORT_T)
+    sg_id = get_import_value(db_name, DB_EXPORT_SG_ID_T)
+    port = get_import_value(db_name, DB_EXPORT_PORT_T)
     SecurityGroupIngress(
         f"AllowRdsFrom{db_name}to{service_stack.title}",
         template=service_template,
         GroupId=sg_id,
         FromPort=port,
         ToPort=port,
-        Description=f"Allow {port}/tcp FROM {db_name} TO {service_stack.title}",
+        Description=Sub(f"Allow FROM {db_name} TO {service_stack.title}"),
         SourceSecurityGroupId=GetAtt(service_template.resources[SG_T], "GroupId"),
         SourceSecurityGroupOwnerId=Ref("AWS::AccountId"),
         IpProtocol="6",
     )
 
 
-def add_secret_to_containers(service_template, db_name, secret_import):
+def db_secrets_names(db_name, db_def):
+    """
+    Function to return the list of env vars set for the DB to use as env vars for the Secret.
+
+    :param db_def: Definition of the DB
+    :return: list of names to use.
+    :rtype: list
+    """
+    names = []
+    if keyisset("Settings", db_def) and keyisset("EnvNames", db_def["Settings"]):
+        names = db_def["Settings"]["EnvNames"]
+    if db_name not in names:
+        names.append(db_name)
+    return names
+
+
+def add_secret_to_containers(
+    service_template, db_name, db_def, secret_import, service_name, family_wide=False
+):
     """
     Function to add DB secret to container
 
     :param troposphere.Template service_template: the ecs_service template
     :param str db_name: the name of the database used as environment variable name
+    :param dict db_def: Definition of the DB.
     :param str secret_import: secret arn
+    :param str service_name: Name of the service that was explicitely listed as consuming the DB
+    :param bool family_wide: Whether or not apply the secret to all services of the family.
     """
 
     containers = define_service_containers(service_template)
-    db_secret = EcsSecret(Name=db_name, ValueFrom=secret_import)
+    db_secrets = [
+        EcsSecret(Name=name, ValueFrom=secret_import)
+        for name in db_secrets_names(db_name, db_def)
+    ]
     for container in containers:
         if (
             isinstance(container, ContainerDefinition)
             and not isinstance(container.Name, (Ref, Sub, GetAtt, ImportValue))
             and container.Name.startswith("AWS")
+            and family_wide
         ):
             LOG.debug(f"Ignoring AWS Container {container.Name}")
             continue
-        if hasattr(container, "Secrets"):
-            secrets = getattr(container, "Secrets")
-            if secrets:
-                secrets.append(db_secret)
-            else:
-                secrets = [db_secret]
-                setattr(container, "Secrets", secrets)
-        else:
-            secrets = [db_secret]
-            setattr(container, "Secrets", secrets)
+        elif family_wide:
+            for db_secret in db_secrets:
+                extend_container_secrets(container, db_secret)
+        elif not family_wide and container.Name == service_name:
+            for db_secret in db_secrets:
+                extend_container_secrets(container, db_secret)
+            break
